@@ -29,6 +29,8 @@ active_class <- R6::R6Class(
     },
     produce_exports = function(envir) {
       out <- as.list(envir, all.names = TRUE)
+      # Eliminate high-memory promise objects:
+      map(names(out), ~force(out[[.x]]))
       names <- fltr(names(out), ~!is_internal_name(.x, envir))
       out[names]
     },
