@@ -17,11 +17,6 @@ pattern_new <- function(
   enclass(environment(), c("tar_pattern", "tar_target"))
 }
 
-#' @export
-target_get_parent.tar_pattern <- function(target) {
-  target_get_name(target)
-}
-
 #' @export
 target_get_children.tar_pattern <- function(target) {
   target$junction$splits
@@ -189,7 +184,7 @@ pattern_insert_branches <- function(target, pipeline, scheduler) {
   branches <- pattern_produce_branches(target, pipeline, scheduler)
   lapply(branches, pipeline_set_target, pipeline = pipeline)
   pattern_engraph_branches(target, pipeline, scheduler)
-  lapply(target_get_children(target), scheduler$progress$assign_queued)
+  lapply(branches, scheduler$progress$assign_queued)
   pattern_enqueue_branches(target, scheduler)
 }
 
@@ -245,7 +240,7 @@ pattern_skip_initial <- function(target, pipeline, scheduler, meta) {
 }
 
 pattern_skip_final <- function(target, pipeline, scheduler, meta) {
-  scheduler$progress$assign_dequeued(target_get_name(target))
+  scheduler$progress$assign_dequeued(target)
   pattern_requeue_downstream_nonbranching(target, pipeline, scheduler)
 }
 
