@@ -21,11 +21,6 @@ stem_new <- function(
   enclass(environment(), c("tar_stem", "tar_builder", "tar_target"))
 }
 
-#' @export
-target_get_parent.tar_stem <- function(target) {
-  target_get_name(target)
-}
-
 #' @export
 target_get_children.tar_stem <- function(target) {
   trn(
